@@ -57,17 +57,17 @@ public:
 	unsigned int		random_seed(void)			const	{ return TestEnv::current_random_seed(); }
 
 	/** ݉ڂ̂Ԃ擾 */
-	int					repeat_counter(void)		const	{ return m_repeat_counter; }
+	int					repeat_counter(void)	const IUTEST_CXX_NOEXCEPT_SPEC	{ return m_repeat_counter; }
 
 public:
 	/** eXg */
-	int				total_test_count(void)		const	{ return m_total_test_num; }
+	int				total_test_count(void)		const IUTEST_CXX_NOEXCEPT_SPEC	{ return m_total_test_num; }
 	/** s/eXg */
-	int				test_to_run_count(void)		const	{ return m_should_run_num; }
+	int				test_to_run_count(void)		const IUTEST_CXX_NOEXCEPT_SPEC	{ return m_should_run_num; }
 	/** seXg */
 	int				failed_test_count(void)		const	{ return get_failed_test_count(); }
 	/** eXg */
-	int				disabled_test_count(void)	const	{ return m_disable_num; }
+	int				disabled_test_count(void)	const IUTEST_CXX_NOEXCEPT_SPEC	{ return m_disable_num; }
 	/** eXg */
 	int				successful_test_count(void)	const	{ return test_to_run_count() - failed_test_count() - test_was_skipped_count(); }
 	/** XLbveXg */
@@ -78,7 +78,7 @@ public:
 	/** eXgP[X̑ */
 	int				total_test_case_count(void)	const	{ return m_testcases.size(); }
 	/** seXgP[X */
-	int				test_case_to_run_count(void)	const
+	int				test_case_to_run_count(void) const
 	{
 		int count=0;
 		for( iuTestCases::const_iterator it = m_testcases.begin(), end=m_testcases.end(); it != end; ++it )
@@ -89,7 +89,7 @@ public:
 		return count;
 	}
 	/** eXgP[X */
-	int				successful_test_case_count(void)	const
+	int				successful_test_case_count(void) const
 	{
 		int count=0;
 		for( iuTestCases::const_iterator it = m_testcases.begin(), end=m_testcases.end(); it != end; ++it )
@@ -100,7 +100,7 @@ public:
 		return count;
 	}
 	/** seXgP[X */
-	int				failed_test_case_count(void)	const
+	int				failed_test_case_count(void) const
 	{
 		int count=0;
 		for( iuTestCases::const_iterator it = m_testcases.begin(), end=m_testcases.end(); it != end; ++it )
@@ -111,14 +111,17 @@ public:
 		return count;
 	}
 
+	/** eXgsȂƂ̃Ug̎擾 */
+	const TestResult* ad_hoc_testresult(void) const IUTEST_CXX_NOEXCEPT_SPEC { return &m_ad_hoc_testresult; }
+
 	/** eXg̎s~b */
-	TimeInMillisec	elapsed_time(void)		const	{ return m_elapsedmsec; }
+	TimeInMillisec	elapsed_time(void)		const IUTEST_CXX_NOEXCEPT_SPEC	{ return m_elapsedmsec; }
 
 	/** eXgP[X̎擾 */
 	const TestCase*	GetTestCase(int index)	const	{ return m_testcases[index]; }
 
 	/** eXgǂ */
-	bool			Passed(void)			const	{ return get_failed_test_count() == 0 && m_ad_hoc_testresult.Passed(); }
+	bool			Passed(void)			const;
 	/** eXgsǂ */
 	bool			Failed(void)			const	{ return !Passed(); }
 
@@ -179,7 +182,6 @@ private:
 	UnitTest(void)
 		: m_repeat_counter(0)
 		, m_init_iutest_count(0)
-		, m_current_testcase(NULL)
 	{
 		// ftHg|[^[Zbg
 		TestEnv::SetGlobalTestPartResultReporter(&m_default_test_part_result_reporter);
@@ -223,7 +225,7 @@ private:
 #if IUTEST_HAS_PARAM_TEST
 public:
 	/** @private */
-	ParamTestCaseHolder&	parameterized_test_registry(void)	{ return m_param_testcase_holder; }
+	ParamTestCaseHolder&	parameterized_test_registry(void) IUTEST_CXX_NOEXCEPT_SPEC { return m_param_testcase_holder; }
 
 private:
 	ParamTestCaseHolder	m_param_testcase_holder;
@@ -234,7 +236,6 @@ private:
 
 	int m_repeat_counter;
 	int m_init_iutest_count;
-	const TestCase*	m_current_testcase;
 	detail::DefaultGlobalTestPartResultReporter	m_default_test_part_result_reporter;
 
 	IUTEST_PP_DISALLOW_COPY_AND_ASSIGN(UnitTest);
