@@ -8,7 +8,7 @@
  * @version		1.0
  *
  * @par			copyright
- * Copyright (C) 2011-2012, Takazumi Shirayanagi\n
+ * Copyright (C) 2011-2013, Takazumi Shirayanagi\n
  * The new BSD License is applied to this software.
  * see LICENSE
 */
@@ -19,7 +19,6 @@
 
 //======================================================================
 // include
-#include "iutest_env.hpp"
 #include "internal/iutest_message.hpp"
 #include "internal/iutest_console.hpp"
 
@@ -83,35 +82,35 @@ public:
 	/**
 	 * @brief	sǂ
 	*/
-	bool		failed(void)	const		{ return m_type != kSuccess && m_type != kWarning; }
+	bool		failed(void)	const IUTEST_CXX_NOEXCEPT_SPEC { return m_type != kSuccess && m_type != kWarning; }
 	/**
 	 * @brief	ǂ
 	*/
-	bool		passed(void)	const		{ return !failed(); }
+	bool		passed(void)	const IUTEST_CXX_NOEXCEPT_SPEC { return !failed(); }
 	/**
 	 * @brief	xǂ
 	*/
-	bool		warning(void)	const		{ return m_type == kWarning; }
+	bool		warning(void)	const IUTEST_CXX_NOEXCEPT_SPEC { return m_type == kWarning; }
 
 	/**
 	 * @brief	vIł͂Ȃsǂ
 	*/
-	bool		nonfatally_failed(void)	const	{ return m_type == kNotFatalFailure; }
+	bool		nonfatally_failed(void)	const IUTEST_CXX_NOEXCEPT_SPEC { return m_type == kNotFatalFailure; }
 
 	/**
 	 * @brief	vIȎsǂ
 	*/
-	bool		fatally_failed(void)	const	{ return m_type == kFatalFailure; }
+	bool		fatally_failed(void)	const IUTEST_CXX_NOEXCEPT_SPEC { return m_type == kFatalFailure; }
 
 	/**
 	 * @brief	R
 	*/
-	const char*	summary(void)	const	{ return message(); }
+	const char*	summary(void) const { return message(); }
 
 	/**
 	 * @brief	ʂ̃^Cv擾
 	*/
-	Type		type(void)	const		{ return m_type; }
+	Type		type(void) const IUTEST_CXX_NOEXCEPT_SPEC { return m_type; }
 
 private:
 	Type	m_type;
@@ -135,12 +134,35 @@ public:
 	 * @param [in]	key		= L[
 	 * @param [in]	value	= l
 	*/
-	TestProperty(const char* key, const char* value)
+	TestProperty(const ::std::string& key, const ::std::string& value)
 		: m_key(key), m_value(value) {}
 
+public:
+	/**
+	 * @brief	l̐ݒ
+	*/
+	void SetValue(const ::std::string& value) { m_value = value; }
 	const char*	key(void)	const	{ return m_key.c_str(); }	//!< L[̎擾
 	const char*	value(void)	const	{ return m_value.c_str(); }	//!< l̎擾
 
+public:
+	/**
+	 * @brief	LȃL[ǂ`FbN
+	 * @retval	true=L
+	 * @retval	false=
+	*/
+	bool Validate(const char** ban_list, size_t size) const
+	{
+		for( int i=0, n=size; i < n; ++i )
+		{
+			if( m_key == ban_list[i] )
+			{
+				return false;
+			}
+		}
+		return true;
+	}
+
 private:
 	friend class TestResult;
 	::std::string m_key;
@@ -155,7 +177,7 @@ class TestResult
 	typedef ::std::vector<TestPartResult>	TestPartResults;
 	typedef ::std::vector<TestProperty>		TestPropertys;
 public:
-	TestResult(void) 
+	TestResult(void)
 		: m_elapsedmsec(0) {}
 
 public:
@@ -193,7 +215,7 @@ public:
 	 * @brief	eXg̎sԂ̎擾
 	 * @return	eXg̎s
 	*/
-	TimeInMillisec	elapsed_time(void)		const	{ return m_elapsedmsec; }
+	TimeInMillisec	elapsed_time(void)		const IUTEST_CXX_NOEXCEPT_SPEC { return m_elapsedmsec; }
 
 	/**
 	 * @brief	ʂ̐擾
@@ -226,7 +248,7 @@ public:
 	 * @brief	s̐擾
 	 * @return	s̐
 	*/
-	int			total_error_count(void)		const
+	int total_error_count(void) const
 	{
 		int count = 0;
 		for( TestPartResults::const_iterator it=m_test_part_results.begin(), end=m_test_part_results.end(); it != end; ++it )
@@ -238,7 +260,7 @@ public:
 
 private:
 	void AddTestPartResult(const TestPartResult& result)	{ m_test_part_results.push_back(result); }
-	void set_elapsed_time(TimeInMillisec time)		{ m_elapsedmsec = time; }
+	void set_elapsed_time(TimeInMillisec time) IUTEST_CXX_NOEXCEPT_SPEC { m_elapsedmsec = time; }
 
 private:
 	void RecordProperty(const TestProperty& prop)
@@ -257,6 +279,11 @@ private:
 	void ClearResult(void)
 	{
 		m_test_part_results.clear();
+	}
+	void Clear(void)
+	{
+		m_test_part_results.clear();
+		m_test_propertys.clear();
 		m_elapsedmsec = 0;
 	}
 	bool HasResult(TestPartResult::Type eType) const
@@ -268,7 +295,9 @@ private:
 		return false;
 	}
 private:
+	friend class UnitTestImpl;
 	friend class TestInfo;
+	friend class TestCase;
 	friend class detail::DefaultGlobalTestPartResultReporter;
 
 	TestPartResults	m_test_part_results;
